searchData={"items":[{"type":"module","title":"Ton","doc":"SDK for TON (The Open Network).","ref":"Ton.html"},{"type":"function","title":"Ton.create_transfer_boc/2","doc":"Create a transfer boc which can be used to submit a transaction","ref":"Ton.html#create_transfer_boc/2"},{"type":"function","title":"Examples - Ton.create_transfer_boc/2","doc":"iex> keypair = Ton.mnemonic_to_keypair(\"rail sound peasant garment bounce trigger true abuse arctic gravity ribbon ocean absurd okay blue remove neck cash reflect sleep hen portion gossip arrow\")\n    iex> wallet = Ton.create_wallet(keypair.public_key)\n    iex> {:ok, to_address} = Ton.parse_address(\"EQAHJQ6gs2NYAXsxsfsucpqhpneZaGP0qCdu9lCEzysMGzst\")\n    iex> params = [seqno: 5, bounce: true, secret_key: keypair.secret_key, value: 1, to_address: to_address, timeout: 60, comment: \"Hello\"]\n    iex> <<181, 238, 156, 114, 65, 1, 2, 1, 0, 176, 0, 1, 225, 136, 0, 5, _tail::binary>> = Ton.create_transfer_boc(wallet, params)","ref":"Ton.html#create_transfer_boc/2-examples"},{"type":"function","title":"Ton.create_wallet/3","doc":"Initializes a `Wallet` struct from public_key, workchain and wallet_id. The version of the wallet contract is v4 r2.","ref":"Ton.html#create_wallet/3"},{"type":"function","title":"Examples - Ton.create_wallet/3","doc":"iex> keypair = Ton.mnemonic_to_keypair(\"rail sound peasant garment bounce trigger true abuse arctic gravity ribbon ocean absurd okay blue remove neck cash reflect sleep hen portion gossip arrow\")\n    iex> %Ton.Wallet{initial_code: _, initial_data: _, workchain: 0, wallet_id: 698983191, public_key: <<73, 245, 11, 185, 76, 95, 180, 99, 83, 74, 157, 13, 240, 216, 227, 155, 203, 147, 16, 149, 137, 218, 246, 81, 151, 233, 21, 28, 55, 119, 64, 47>>} = Ton.create_wallet(keypair.public_key)","ref":"Ton.html#create_wallet/3-examples"},{"type":"function","title":"Ton.generate_mnemonic/1","doc":"Generate a random mnemonic with the given number of words (24 by default).\nSee https://github.com/bitcoin/bips/blob/master/bip-0039.mediawiki\n\nExamples:\n\n    iex> mnemonic1 = Ton.generate_mnemonic()\n    iex> mnemonic2 = Ton.generate_mnemonic()\n    iex> mnemonic1 |> String.split(\" \") |> Enum.count()\n    24\n    iex> mnemonic1 != mnemonic2\n    true","ref":"Ton.html#generate_mnemonic/1"},{"type":"function","title":"Ton.mnemonic_to_entropy/2","doc":"Converts a mnemonic to an entropy.","ref":"Ton.html#mnemonic_to_entropy/2"},{"type":"function","title":"Examples - Ton.mnemonic_to_entropy/2","doc":"iex> Ton.mnemonic_to_entropy(\"rail sound peasant garment bounce trigger true abuse arctic gravity ribbon ocean absurd okay blue remove neck cash reflect sleep hen portion gossip arrow\")\n    # \"1ab77da4f35581bd6f8efdcaef689ec180c6f77d214e4dd960f1619f6c40599f04798cb4e93e30edceeb02ab36f450df1c359e7b3395f13646134046cc6a7f3a\"\n    <<26, 183, 125, 164, 243, 85, 129, 189, 111, 142, 253, 202, 239, 104, 158, 193, 128, 198, 247, 125, 33, 78, 77, 217, 96, 241, 97, 159, 108, 64, 89, 159, 4, 121, 140, 180, 233, 62, 48, 237, 206, 235, 2, 171, 54, 244, 80, 223, 28, 53, 158, 123, 51, 149, 241, 54, 70, 19, 64, 70, 204, 106, 127, 58>>","ref":"Ton.html#mnemonic_to_entropy/2-examples"},{"type":"function","title":"Ton.mnemonic_to_keypair/2","doc":"Generates a key pair from a mnemonic.","ref":"Ton.html#mnemonic_to_keypair/2"},{"type":"function","title":"Examples - Ton.mnemonic_to_keypair/2","doc":"iex> Ton.mnemonic_to_keypair(\"rail sound peasant garment bounce trigger true abuse arctic gravity ribbon ocean absurd okay blue remove neck cash reflect sleep hen portion gossip arrow\")\n    %Ton.KeyPair{\n      secret_key: <<149, 222, 63, 223, 23, 72, 240, 224, 233, 177, 155, 16, 101,\n        229, 182, 172, 23, 131, 54, 43, 195, 139, 217, 194, 100, 19, 252, 105, 68,\n        30, 96, 95, 73, 245, 11, 185, 76, 95, 180, 99, 83, 74, 157, 13, 240, 216,\n        227, 155, 203, 147, 16, 149, 137, 218, 246, 81, 151, 233, 21, 28, 55, 119,\n        64, 47>>,\n      public_key: <<73, 245, 11, 185, 76, 95, 180, 99, 83, 74, 157, 13, 240, 216,\n        227, 155, 203, 147, 16, 149, 137, 218, 246, 81, 151, 233, 21, 28, 55, 119,\n        64, 47>>\n    }","ref":"Ton.html#mnemonic_to_keypair/2-examples"},{"type":"function","title":"Ton.mnemonic_to_seed/2","doc":"Converts a mnemonic to a seed.","ref":"Ton.html#mnemonic_to_seed/2"},{"type":"function","title":"Examples - Ton.mnemonic_to_seed/2","doc":"iex> Ton.mnemonic_to_seed(\"rail sound peasant garment bounce trigger true abuse arctic gravity ribbon ocean absurd okay blue remove neck cash reflect sleep hen portion gossip arrow\")\n    # 95de3fdf1748f0e0e9b19b1065e5b6ac1783362bc38bd9c26413fc69441e605f\n    <<149, 222, 63, 223, 23, 72, 240, 224, 233, 177, 155, 16, 101, 229, 182, 172, 23, 131, 54, 43, 195, 139, 217, 194, 100, 19, 252, 105, 68, 30, 96, 95>>","ref":"Ton.html#mnemonic_to_seed/2-examples"},{"type":"function","title":"Ton.parse_address/1","doc":"Parses and validates an address","ref":"Ton.html#parse_address/1"},{"type":"function","title":"Examples - Ton.parse_address/1","doc":"iex> Ton.parse_address(\"UQCAIBANQeQX6UHmRgxHGR44oUL7VOQE9v4dxmla23KpjKIj\")\n    {:ok, %Ton.Address{test_only: false, bounceable: false, workchain: 0, hash: <<128, 32, 16, 13, 65, 228, 23, 233, 65, 230, 70, 12, 71, 25, 30, 56, 161, 66, 251, 84, 228, 4, 246, 254, 29, 198, 105, 90, 219, 114, 169, 140>>}}\n\n    iex> Ton.parse_address(\"address\")\n    {:error, :invalid_base64}","ref":"Ton.html#parse_address/1-examples"},{"type":"function","title":"Ton.wallet_to_friendly_address/2","doc":"Generates a friendly address from a wallet struct","ref":"Ton.html#wallet_to_friendly_address/2"},{"type":"function","title":"Examples - Ton.wallet_to_friendly_address/2","doc":"iex> keypair = Ton.mnemonic_to_keypair(\"rail sound peasant garment bounce trigger true abuse arctic gravity ribbon ocean absurd okay blue remove neck cash reflect sleep hen portion gossip arrow\")\n    iex> wallet = Ton.create_wallet(keypair.public_key)\n    iex> Ton.wallet_to_friendly_address(wallet)\n    \"EQAC824gsw8OZLoMV6_nr4nkxaEQFlbzoiHHOWIYY81eM5rQ\"\n\n    iex> keypair = Ton.mnemonic_to_keypair(\"rail sound peasant garment bounce trigger true abuse arctic gravity ribbon ocean absurd okay blue remove neck cash reflect sleep hen portion gossip arrow\")\n    iex> wallet = Ton.create_wallet(keypair.public_key)\n    iex> Ton.wallet_to_friendly_address(wallet, [url_safe: false, bounceable: false, test_only: true])\n    \"0QAC824gsw8OZLoMV6/nr4nkxaEQFlbzoiHHOWIYY81eM3yf\"","ref":"Ton.html#wallet_to_friendly_address/2-examples"},{"type":"function","title":"Ton.wallet_to_raw_address/1","doc":"Generates a raw address from a wallet struct","ref":"Ton.html#wallet_to_raw_address/1"},{"type":"function","title":"Examples - Ton.wallet_to_raw_address/1","doc":"iex> keypair = Ton.mnemonic_to_keypair(\"rail sound peasant garment bounce trigger true abuse arctic gravity ribbon ocean absurd okay blue remove neck cash reflect sleep hen portion gossip arrow\")\n    iex> wallet = Ton.create_wallet(keypair.public_key)\n    iex> Ton.wallet_to_raw_address(wallet)\n    \"0:02f36e20b30f0e64ba0c57afe7af89e4c5a1101656f3a221c739621863cd5e33\"\n\n    iex> keypair = Ton.mnemonic_to_keypair(\"rail sound peasant garment bounce trigger true abuse arctic gravity ribbon ocean okay absurd blue remove neck cash reflect sleep hen portion gossip arrow\")\n    iex> wallet = Ton.create_wallet(keypair.public_key)\n    iex> Ton.wallet_to_raw_address(wallet)\n    \"0:9f48f826d3f5d2a986d7af82504b7f036be62a8168c8e0409f32ddbe06565780\"","ref":"Ton.html#wallet_to_raw_address/1-examples"},{"type":"module","title":"Ton.Address","doc":"Functions for parsing, validation and serialization of TON addresses.","ref":"Ton.Address.html"},{"type":"function","title":"Ton.Address.do_friendly_address/1","doc":"","ref":"Ton.Address.html#do_friendly_address/1"},{"type":"function","title":"Ton.Address.friendly_address/2","doc":"","ref":"Ton.Address.html#friendly_address/2"},{"type":"function","title":"Ton.Address.parse/1","doc":"","ref":"Ton.Address.html#parse/1"},{"type":"function","title":"Ton.Address.raw_address/1","doc":"","ref":"Ton.Address.html#raw_address/1"},{"type":"function","title":"Ton.Address.raw_address_to_friendly_address/2","doc":"","ref":"Ton.Address.html#raw_address_to_friendly_address/2"},{"type":"type","title":"Ton.Address.t/0","doc":"","ref":"Ton.Address.html#t:t/0"},{"type":"module","title":"Ton.Bitstring","doc":"Defines an array of bits. Data structure used in cells","ref":"Ton.Bitstring.html"},{"type":"function","title":"Ton.Bitstring.available/1","doc":"","ref":"Ton.Bitstring.html#available/1"},{"type":"function","title":"Ton.Bitstring.get_bit/2","doc":"","ref":"Ton.Bitstring.html#get_bit/2"},{"type":"function","title":"Ton.Bitstring.get_top_upped_array/1","doc":"","ref":"Ton.Bitstring.html#get_top_upped_array/1"},{"type":"function","title":"Ton.Bitstring.get_top_upped_length/1","doc":"","ref":"Ton.Bitstring.html#get_top_upped_length/1"},{"type":"function","title":"Ton.Bitstring.new/1","doc":"","ref":"Ton.Bitstring.html#new/1"},{"type":"function","title":"Ton.Bitstring.off_bit/2","doc":"","ref":"Ton.Bitstring.html#off_bit/2"},{"type":"function","title":"Ton.Bitstring.on_bit/2","doc":"","ref":"Ton.Bitstring.html#on_bit/2"},{"type":"function","title":"Ton.Bitstring.set_top_upped_array/2","doc":"","ref":"Ton.Bitstring.html#set_top_upped_array/2"},{"type":"function","title":"Ton.Bitstring.write_address/2","doc":"","ref":"Ton.Bitstring.html#write_address/2"},{"type":"function","title":"Ton.Bitstring.write_binary/2","doc":"","ref":"Ton.Bitstring.html#write_binary/2"},{"type":"function","title":"Ton.Bitstring.write_bistring/2","doc":"","ref":"Ton.Bitstring.html#write_bistring/2"},{"type":"function","title":"Ton.Bitstring.write_bit/2","doc":"","ref":"Ton.Bitstring.html#write_bit/2"},{"type":"function","title":"Ton.Bitstring.write_coins/2","doc":"","ref":"Ton.Bitstring.html#write_coins/2"},{"type":"function","title":"Ton.Bitstring.write_uint8/2","doc":"","ref":"Ton.Bitstring.html#write_uint8/2"},{"type":"function","title":"Ton.Bitstring.write_uint/3","doc":"","ref":"Ton.Bitstring.html#write_uint/3"},{"type":"type","title":"Ton.Bitstring.t/0","doc":"","ref":"Ton.Bitstring.html#t:t/0"},{"type":"module","title":"Ton.Boc","doc":"Deserialization of cells from a header","ref":"Ton.Boc.html"},{"type":"function","title":"Ton.Boc.parse/1","doc":"","ref":"Ton.Boc.html#parse/1"},{"type":"module","title":"Ton.Boc.Header","doc":"Logic used for contract deserialization from the BOC format","ref":"Ton.Boc.Header.html"},{"type":"function","title":"Ton.Boc.Header.lean_boc_magic_prefix/0","doc":"","ref":"Ton.Boc.Header.html#lean_boc_magic_prefix/0"},{"type":"function","title":"Ton.Boc.Header.lean_boc_magic_prefix_crc/0","doc":"","ref":"Ton.Boc.Header.html#lean_boc_magic_prefix_crc/0"},{"type":"function","title":"Ton.Boc.Header.parse/1","doc":"","ref":"Ton.Boc.Header.html#parse/1"},{"type":"function","title":"Ton.Boc.Header.reach_boc_magic_prefix/0","doc":"","ref":"Ton.Boc.Header.html#reach_boc_magic_prefix/0"},{"type":"type","title":"Ton.Boc.Header.t/0","doc":"","ref":"Ton.Boc.Header.html#t:t/0"},{"type":"module","title":"Ton.Cell","doc":"Cell data structure used in serialization and deserialization","ref":"Ton.Cell.html"},{"type":"function","title":"Ton.Cell.hash/1","doc":"","ref":"Ton.Cell.html#hash/1"},{"type":"function","title":"Ton.Cell.new/2","doc":"","ref":"Ton.Cell.html#new/2"},{"type":"function","title":"Ton.Cell.parse/2","doc":"","ref":"Ton.Cell.html#parse/2"},{"type":"function","title":"Ton.Cell.serialize/2","doc":"","ref":"Ton.Cell.html#serialize/2"},{"type":"function","title":"Ton.Cell.write_cell/2","doc":"","ref":"Ton.Cell.html#write_cell/2"},{"type":"type","title":"Ton.Cell.cell_kind/0","doc":"","ref":"Ton.Cell.html#t:cell_kind/0"},{"type":"type","title":"Ton.Cell.t/0","doc":"","ref":"Ton.Cell.html#t:t/0"},{"type":"module","title":"Ton.Cell.TopologicalOrder","doc":"Cell ordering algorithm","ref":"Ton.Cell.TopologicalOrder.html"},{"type":"function","title":"Ton.Cell.TopologicalOrder.sort/1","doc":"","ref":"Ton.Cell.TopologicalOrder.html#sort/1"},{"type":"module","title":"Ton.Comment","doc":"Logic for comment serialization","ref":"Ton.Comment.html"},{"type":"function","title":"Ton.Comment.serialize/2","doc":"","ref":"Ton.Comment.html#serialize/2"},{"type":"module","title":"Ton.CommonMessageInfo","doc":"Common message info used in an external message","ref":"Ton.CommonMessageInfo.html"},{"type":"function","title":"Ton.CommonMessageInfo.new/2","doc":"","ref":"Ton.CommonMessageInfo.html#new/2"},{"type":"function","title":"Ton.CommonMessageInfo.serialize/2","doc":"","ref":"Ton.CommonMessageInfo.html#serialize/2"},{"type":"type","title":"Ton.CommonMessageInfo.t/0","doc":"","ref":"Ton.CommonMessageInfo.html#t:t/0"},{"type":"module","title":"Ton.ExternalMessage","doc":"An external message required to make transfers","ref":"Ton.ExternalMessage.html"},{"type":"function","title":"Ton.ExternalMessage.new/2","doc":"","ref":"Ton.ExternalMessage.html#new/2"},{"type":"function","title":"Ton.ExternalMessage.serialize/2","doc":"","ref":"Ton.ExternalMessage.html#serialize/2"},{"type":"type","title":"Ton.ExternalMessage.t/0","doc":"","ref":"Ton.ExternalMessage.html#t:t/0"},{"type":"module","title":"Ton.KeyPair","doc":"Pair of public and secret keys used for wallet operations","ref":"Ton.KeyPair.html"},{"type":"function","title":"Ton.KeyPair.new/2","doc":"","ref":"Ton.KeyPair.html#new/2"},{"type":"type","title":"Ton.KeyPair.t/0","doc":"","ref":"Ton.KeyPair.html#t:t/0"},{"type":"module","title":"Ton.Transfer","doc":"Defines an actual transfer","ref":"Ton.Transfer.html"},{"type":"function","title":"Ton.Transfer.new/1","doc":"","ref":"Ton.Transfer.html#new/1"},{"type":"function","title":"Ton.Transfer.serialize/2","doc":"","ref":"Ton.Transfer.html#serialize/2"},{"type":"function","title":"Ton.Transfer.serialize_and_sign/2","doc":"","ref":"Ton.Transfer.html#serialize_and_sign/2"},{"type":"type","title":"Ton.Transfer.t/0","doc":"","ref":"Ton.Transfer.html#t:t/0"},{"type":"module","title":"Ton.Utils","doc":"Various utility functions","ref":"Ton.Utils.html"},{"type":"function","title":"Ton.Utils.read_n_bytes_uint/2","doc":"","ref":"Ton.Utils.html#read_n_bytes_uint/2"},{"type":"function","title":"Ton.Utils.sha256/1","doc":"","ref":"Ton.Utils.html#sha256/1"},{"type":"function","title":"Ton.Utils.sign/2","doc":"","ref":"Ton.Utils.html#sign/2"},{"type":"module","title":"Ton.Wallet","doc":"Defines a wallet","ref":"Ton.Wallet.html"},{"type":"function","title":"Ton.Wallet.create/3","doc":"","ref":"Ton.Wallet.html#create/3"},{"type":"function","title":"Ton.Wallet.hash/1","doc":"","ref":"Ton.Wallet.html#hash/1"},{"type":"function","title":"Ton.Wallet.state_init_cell/2","doc":"","ref":"Ton.Wallet.html#state_init_cell/2"},{"type":"type","title":"Ton.Wallet.t/0","doc":"","ref":"Ton.Wallet.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}